summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChris <[email protected]>2021-07-25 02:09:17 -0400
committerChris <[email protected]>2021-07-25 02:09:17 -0400
commit96c5ff62f8eb6517d0c774856c25135e7042374a (patch)
treecf1691469e4e6fffa367798f4ce92f595faee19c
parentfb439b7309be1ede206143319ea85288cfa57eb1 (diff)
parentceb018d45d0194bb0f8954aecffea4ac1549d906 (diff)
Merge branch 'rolling' of github.com:ChristianChiarulli/LunarVim into rolling
-rw-r--r--lua/default-config.lua66
-rw-r--r--lua/lv-utils/init.lua8
2 files changed, 70 insertions, 4 deletions
diff --git a/lua/default-config.lua b/lua/default-config.lua
index 0d874a67..c8588ee3 100644
--- a/lua/default-config.lua
+++ b/lua/default-config.lua
@@ -497,6 +497,28 @@ lvim.lang = {
},
},
},
+ javascriptreact = {
+ -- @usage can be prettier or eslint
+ formatter = {
+ exe = "prettier",
+ args = {},
+ },
+ linters = {
+ "eslint",
+ },
+ lsp = {
+ provider = "tsserver",
+ setup = {
+ cmd = {
+ -- TODO:
+ DATA_PATH .. "/lspinstall/typescript/node_modules/.bin/typescript-language-server",
+ "--stdio",
+ },
+ on_attach = require("lsp").common_on_attach,
+ capabilities = require("lsp").common_capabilities(),
+ },
+ },
+ },
python = {
-- @usage can be flake8 or yapf
formatter = {
@@ -664,6 +686,50 @@ lvim.lang = {
},
},
},
+ typescript = {
+ -- @usage can be prettier or eslint
+ formatter = {
+ exe = "prettier",
+ args = {},
+ },
+ linters = {
+ "eslint",
+ },
+ lsp = {
+ provider = "tsserver",
+ setup = {
+ cmd = {
+ -- TODO:
+ DATA_PATH .. "/lspinstall/typescript/node_modules/.bin/typescript-language-server",
+ "--stdio",
+ },
+ on_attach = require("lsp").common_on_attach,
+ capabilities = require("lsp").common_capabilities(),
+ },
+ },
+ },
+ typescriptreact = {
+ -- @usage can be prettier or eslint
+ formatter = {
+ exe = "prettier",
+ args = {},
+ },
+ linters = {
+ "eslint",
+ },
+ lsp = {
+ provider = "tsserver",
+ setup = {
+ cmd = {
+ -- TODO:
+ DATA_PATH .. "/lspinstall/typescript/node_modules/.bin/typescript-language-server",
+ "--stdio",
+ },
+ on_attach = require("lsp").common_on_attach,
+ capabilities = require("lsp").common_capabilities(),
+ },
+ },
+ },
vim = {
formatter = {
exe = "",
diff --git a/lua/lv-utils/init.lua b/lua/lv-utils/init.lua
index d97c7c30..5bf8ea00 100644
--- a/lua/lv-utils/init.lua
+++ b/lua/lv-utils/init.lua
@@ -35,9 +35,9 @@ local function r_inspect_settings(structure, limit, separator)
separator = separator:gsub("%.%[", "%[")
if type(structure) == "function" then
-- don't print functions
- io.write("-- O", separator:sub(2), " = function ()\n")
+ io.write("-- lvim", separator:sub(2), " = function ()\n")
else
- io.write("O", separator:sub(2), " = ", tostring(structure), "\n")
+ io.write("lvim", separator:sub(2), " = ", tostring(structure), "\n")
end
return limit - 1
end
@@ -49,8 +49,8 @@ function lv_utils.generate_settings()
-- sets the default output file as test.lua
io.output(file)
- -- write all `O` related settings to `lv-settings.lua` file
- r_inspect_settings(O, 10000, ".")
+ -- write all `lvim` related settings to `lv-settings.lua` file
+ r_inspect_settings(lvim, 10000, ".")
-- closes the open file
io.close(file)